@@ -53,7 +53,12 @@ class Provider(BaseProvider):
         if self.options.get('ttl'):
             record['ttl'] = self.options.get('ttl')
 
-        payload = self._post('/record', record)
+        try:
+            payload = self._post('/record', record)
+        except requests.exceptions.HTTPError as err:
+            already_exists = (err.response.json()['code'] == 34)
+            if not already_exists:
+                raise
 
         logger.debug('create_record: %s', True) # CloudXNS will return bad HTTP Status when error, will throw at r.raise_for_status() in _request()
         return True
@@ -117,15 +122,17 @@ class Provider(BaseProvider):
     # Delete an existing record.
     # If record does not exist, do nothing.
     def delete_record(self, identifier=None, type=None, name=None, content=None):
-
+        delete_record_id = []
         if not identifier:
             records = self.list_records(type, name, content)
-            if len(records) == 1:
-                identifier = records[0]['id']
-            else:
-                raise Exception('Record identifier could not be found.')
+            delete_record_id = [record['id'] for record in records]
+        else:
+            delete_record_id.append(identifier)
 
-        payload = self._delete('/record/' + identifier + '/' + self.domain_id)
+        logger.debug('delete_records: %s', delete_record_id)
+
+        for record_id in delete_record_id:
+            payload = self._delete('/record/' + record_id + '/' + self.domain_id)
 
         # is always True at this point, if a non 200 response is returned an error is raised.
         logger.debug('delete_record: %s', True)
